@@ -1,4 +1,5 @@
-import os, code, sys, traceback, logging, StringIO, re, threading, urlparse, weakref, math
+import logging
+import urlparse
 
 import cairo
 import pango
@@ -14,6 +15,7 @@ from bigboard.libbig.logutil import log_except
 import libbig, stock, globals, bigboard
 from bigboard.libbig.signalobject import SignalObject
 from bigboard.libbig.singletonmixin import Singleton
+from bigboard.theme_manager import ThemeManager
 from table_layout import TableLayout
 
 _logger = logging.getLogger("bigboard.BigWidgets")
@@ -34,84 +36,49 @@ class CanvasSpinner(hippo.CanvasWidget):
         self.spinner = gtk.SpinButton()
         self.set_property('widget', self.spinner)
 
-class ThemeManager(gobject.GObject):
-    __gsignals__ = {
-                    'theme-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ()),
-                   }
-    def __init__(self):
-        super(ThemeManager, self).__init__()
-        self.__class__.instance = weakref.ref(self)
-        self.__default_theme = None
-        self.__theme = None
-        gconf.client_get_default().notify_add('/apps/bigboard/theme', self.__sync_theme)
-        self.__sync_theme()
-        
-    @staticmethod
-    def getInstance():
-        needinst = False
-        if not hasattr(ThemeManager, 'instance'):
-            instvalue = None
-        else:
-            instref = getattr(ThemeManager, 'instance')
-            instvalue = instref()
-            needinst = instvalue is None
-        if instvalue is None:
-            inst = ThemeManager()
-        else:
-            inst = instvalue
-        return inst
-
-    def __make_theme(self, themename):
-        is_default = False
-        if themename == 'Fedora':
-            import bigboard.themes.fedora as package
-        else:
-            if self.__default_theme != None:
-                return self.__default_theme
-            
-            import bigboard.themes.default as package
-            is_default = True
-
-        theme_engine = package.getInstance()
-        stylesheet_name = re.sub(r"\.[^.]*$", ".css", package.__file__)
-
-        theme = hippo.CanvasTheme(theme_engine = theme_engine, theme_stylesheet = stylesheet_name)
-        if is_default and self.__default_theme == None:
-            self.__default_theme = theme
-
-        return theme
-        
-    def get_theme(self):
-        return self.__theme
-
-    def get_default_theme(self):
-        return self.__make_theme('default')
-        
-    @log_except(_logger)
-    def __sync_theme(self, *args):
-        themename = gconf.client_get_default().get_string('/apps/bigboard/theme')
-        _logger.debug("doing theme sync: <THEMENAME>%r</THEMENAME>", themename)
-        
-        self.__theme = self.__make_theme(themename)
-        self.emit('theme-changed')            
-         
 class BigWindow(hippo.CanvasWindow):
     __gsignals__ = {
         'destroy' : 'override',
         }
     
-    def __init__(self, themed=True, **kwargs):
+    def __init__(self, stylesheet=None, themed=True, **kwargs):
         super(BigWindow, self).__init__(**kwargs)
 
+        self.__stylesheet = stylesheet
+
+        theme_mgr = ThemeManager.getInstance()
+
+        colormap = None
+        if theme_mgr.composited:
+            colormap = self.get_screen().get_rgba_colormap()
+
+        if colormap == None:
+            colormap = self.get_screen().get_rgb_colormap()
+            
+        self.set_colormap(colormap)
+
         if themed:
-            self.__connection = ThemeManager.getInstance().connect('theme-changed', self.__sync_theme)
+            self.__connection = theme_mgr.connect('theme-changed', self.__sync_theme)
             self.__sync_theme()
         else:
             self.__connection = None
-            self.set_theme(ThemeManager.getInstance().get_default_theme())            
+
+            if self.__stylesheet:
+                theme = theme_mgr.make_stock_theme(self.__stylesheet, default=True)
+            else:
+                theme = theme_mgr.get_default_theme()
+
+            self.set_theme(theme)
 
     def __sync_theme(self, *args):
-        self.set_theme(ThemeManager.getInstance().get_theme())
+        theme_mgr = ThemeManager.getInstance()
+
+        if self.__stylesheet:
+            theme = theme_mgr.make_stock_theme(self.__stylesheet)
+        else:
+            theme = theme_mgr.get_theme()
+
+        self.set_theme(theme)
 
     def do_destroy(self):
         if self.__connection:
@@ -119,23 +86,6 @@ class BigWindow(hippo.CanvasWindow):
             self.__connection = None
         hippo.CanvasWindow.destroy(self)
 
-class ThemedWidgetMixin(object):
-    def __init__(self):
-        super(ThemedWidgetMixin, self).__init__()
-        mgr = ThemeManager.getInstance()
-        mgr.connect('theme-changed', self.__sync_theme)
-        self.__sync_theme(mgr)
-        
-    def get_theme(self):
-        return ThemeManager.getInstance().get_theme()
-    
-    def _on_theme_changed(self, theme):
-        pass
-
-    def __sync_theme(self, tm):
-        theme = tm.get_theme()
-        self._on_theme_changed(theme)             
-        
 class CanvasCheckbox(hippo.CanvasWidget):
     def __init__(self, label):
         super(CanvasCheckbox, self).__init__()
@@ -190,17 +140,18 @@ class Arrow(hippo.CanvasBox):
 
     MIN_SIZE = 12
 
-    def __init__(self, arrow_type, **kwargs):
+    def __init__(self, arrow_type, arrow_size = MIN_SIZE, **kwargs):
         gobject.GObject.__init__(self, **kwargs)
         self.__arrow_type = arrow_type
+        self.__arrow_size = arrow_size     
 
         self.set_clickable(True)
 
     def do_get_content_width_request(self):
-        return (self.MIN_SIZE, self.MIN_SIZE)
+        return (self.__arrow_size, self.__arrow_size)
 
     def do_get_content_height_request(self, for_width):
-        return (self.MIN_SIZE, self.MIN_SIZE)
+        return (self.__arrow_size, self.__arrow_size)
 
     def do_paint_below_children(self, cr, dmgbox):
         [w, h] = self.get_allocation()
@@ -233,15 +184,9 @@ class Arrow(hippo.CanvasBox):
         cr.close_path()
         cr.fill()
 
-class GradientHeader(hippo.CanvasGradient):
-    def __init__(self, **kwargs):
-        hippo.CanvasGradient.__init__(self, 
-                                      orientation=hippo.ORIENTATION_HORIZONTAL,
-                                      start_color=0xF4F4F4FF, 
-                                      end_color=0xC7C7C7FF,
-                                      padding_left=4,
-                                      color=0x333333FF, **kwargs)        
-        
+    def get_arrow_type(self):
+        return self.__arrow_type
+
 class ActionLink(hippo.CanvasLink):
     def __init__(self, underline=pango.UNDERLINE_NONE, **kwargs):
         hippo.CanvasLink.__init__(self, **kwargs)
@@ -258,17 +203,6 @@ class ActionLink(hippo.CanvasLink):
         if len(attrs.get_iterator().get_attrs()) == 1: 
             self.set_property("attributes", attrs)
             
-class ButtonLabel(gtk.Label):
-    def __init__(self, ypadding=0):
-        super(ButtonLabel, self).__init__()
-        self.__ypadding = ypadding
-    
-    def do_size_request(self, req):
-        gtk.Label.do_size_request(self, req)
-        req.height += (self.__ypadding*2)
-
-gobject.type_register(ButtonLabel)
-
 class Button(hippo.CanvasButton):
     def __init__(self, label_xpadding=0, label_ypadding=0, label=''):
         super(Button, self).__init__()
@@ -284,7 +218,7 @@ class Button(hippo.CanvasButton):
 
         # Avoid some padding
         button.set_name('bigboard-nopad-button')
-        child = button.get_child() #gtk.Label() #ButtonLabel(ypadding=label_ypadding)
+        child = button.get_child()
         child.set_alignment(0.5, 0)
         child.set_padding(self.__label_xpadding, self.__label_ypadding)
 
@@ -371,12 +305,6 @@ class CanvasURLImageButton(hippo.CanvasImageButton, CanvasURLImageMixin):
         hippo.CanvasImageButton.__init__(self, **kwargs)
         CanvasURLImageMixin.__init__(self, url)
         self._set_is_button(True)
-        
-class CanvasMugshotURLImageButton(CanvasMugshotURLImageMixin, CanvasURLImageButton):
-    """A canvas image button that takes a Mugshot-relative image URL."""
-    def __init__(self, url=None, **kwargs):
-        CanvasURLImageButton.__init__(self, **kwargs)
-        CanvasMugshotURLImageMixin.__init__(self, url)
 
 class Separator(hippo.CanvasBox):
     def __init__(self):
