@@ -1,8 +1,6 @@
-import logging
+import logging, dbus, gtk
 import hippo
 import bigboard.google as google
-import bigboard.accounts as accounts
-import accounts_dialog
 import bigboard.libbig.gutil as gutil
 from bigboard.libbig.logutil import log_except
 
@@ -25,7 +23,9 @@ class GoogleStock(object):
         _logger.debug("in google stock init")
         # a set of enabled google accounts to be used in the stock
         self.googles = set()
-        self.__googles_by_account = {} ## map accounts.Account => google.Google
+        self.__googles_by_account = {} ## maps OnlineAccount ObjectPath => google.Google
+
+        self.__onlineaccounts_proxy = None
 
         _logger.debug("in google stock init action_id is %s", str(action_id))         
         self.__action_id = action_id
@@ -37,13 +37,26 @@ class GoogleStock(object):
         _logger.debug("done with google stock init")     
 
     def _post_init(self):
-        accts = accounts.get_accounts()
-        for a in accts.get_accounts_with_kind(accounts.KIND_GOOGLE):
-            self.__on_account_added(a)
-        id = accts.connect('account-added', lambda accounts, account: self.__on_account_added(account))
-        self.__connections.add(accts, id)
-        id = accts.connect('account-removed', lambda accounts, account: self.__on_account_removed(account))
-        self.__connections.add(accts, id)   
+        try:
+            self.__onlineaccounts_proxy = dbus.SessionBus().get_object('org.gnome.OnlineAccounts', '/onlineaccounts')
+        except dbus.DBusException, e:
+            _logger.error("onlineaccounts DBus service not available, can't get google accounts")
+            return
+
+        try: 
+            self.__onlineaccounts_proxy.EnsureAccountType("google", "Google", "Gmail or Google Apps for Your Domain email", "http://gmail.com")
+        except dbus.DBusException, e:
+            _logger.error(e.message)
+            return
+
+        all_google_account_paths = self.__onlineaccounts_proxy.GetEnabledAccountsWithTypes(["google"])
+        for a_path in all_google_account_paths:
+            self.__on_account_added(a_path)
+
+        id = self.__onlineaccounts_proxy.connect_to_signal('AccountEnabled', self.__on_account_added)
+        self.__connections.add(self.__onlineaccounts_proxy, id)
+        id = self.__onlineaccounts_proxy.connect_to_signal('AccountDisabled', self.__on_account_removed)
+        self.__connections.add(self.__onlineaccounts_proxy, id)
 
     ## we can't just override _on_delisted() because of multiple inheritance,
     ## so our subclasses have to override it then call this
@@ -51,28 +64,47 @@ class GoogleStock(object):
         self.__connections.disconnect_all()
 
         ## detach from all the accounts
-        accts = self.__googles_by_account.keys()
-        for a in accts:
-            self.__on_account_removed(a)
+        acct_paths = self.__googles_by_account.keys()
+        for a_path in acct_paths:
+            self.__on_account_removed(a_path)
 
     @log_except(_logger)
-    def __on_account_added(self, acct):
+    def __on_account_added(self, acct_path):
+        try:
+            _logger.debug("acct_path is %s" % acct_path)
+            acct = dbus.SessionBus().get_object('org.gnome.OnlineAccounts', acct_path)
+        except dbus.DBusException, e:
+            _logger.error("onlineaccount for path %s was not found" % acct_path)
+            return
+
+        if acct.GetType() != "google":
+            return
+       
         _logger.debug("in __on_account_added for %s", str(acct))         
         gobj = google.get_google_for_account(acct)
         gobj.add_poll_action_func(self.__action_id, lambda gobj: self.update_google_data(gobj))
         self.googles.add(gobj)
-        self.__googles_by_account[acct] = gobj
+        self.__googles_by_account[acct_path] = gobj
         gobj.connect("checking-auth", self._checking_google_auth)
         ## update_google_data() should be called in the poll action
     
-    def __on_account_removed(self, acct):
+    def __on_account_removed(self, acct_path):
+        try:
+            acct = dbus.SessionBus().get_object('org.gnome.OnlineAccounts', acct_path)
+        except dbus.DBusException, e:
+            _logger.error("onlineaccount for path %s was not found" % acct_path)
+            return
+
+        if acct.GetType() != "google":
+            return
+
         _logger.debug("in __on_account_removed for %s", str(acct))  
         ## we keep our own __googles_by_account because google.get_google_for_account()
         ## will have dropped the Google before this point
-        gobj = self.__googles_by_account[acct]
+        gobj = self.__googles_by_account[acct_path]
         gobj.remove_poll_action(self.__action_id)
         self.googles.remove(gobj)
-        del self.__googles_by_account[acct]
+        del self.__googles_by_account[acct_path]
 
         ## hook for derived classes
         self.remove_google_data(gobj)
@@ -85,7 +117,10 @@ class GoogleStock(object):
         return False
 
     def __open_login_dialog(self):
-        accounts_dialog.open_dialog()
+        if self.__onlineaccounts_proxy:
+            self.__onlineaccounts_proxy.OpenAccountsDialogWithTypes(["google"], gtk.get_current_event_time())
+        else: 
+            _logger.error("onlineaccounts proxy is not initialized, can't open the dialog for google accounts")    
 
     def _checking_google_auth(self, gobj):
         self._login_button.set_property("text", CHECKING_LOGIN_STRING)
