@@ -53,5 +53,12 @@ qualname=%s%s
         """ % (module, prefix or "",module)
         )
     logging.config.fileConfig(StringIO.StringIO(logging_config.getvalue()))
+
+    # After parsing the config, logging disables any loggers that it doesn't
+    # know about, like loggers we created before we initialized logging.
+    # grrr. Reenable them. A different workaround would be to replace
+    # parsing a config file with manual manipulation of loggers and handlers
+    for logger in logging.root.manager.loggerDict.values():
+        logger.disabled = 0
     
     logging.debug("Initialized logging")
