@@ -41,7 +41,7 @@ class AppOverview(CanvasVBox):
         
         self.__header = apps_widgets.AppDisplay(apps_widgets.AppLocation.DESCRIPTION_HEADER)
         
-        self.__description = hippo.CanvasText(font="12px",size_mode=hippo.CANVAS_SIZE_WRAP_WORD)
+        self.__description = hippo.CanvasText(id="app-description",size_mode=hippo.CANVAS_SIZE_WRAP_WORD)
         
         self.__controls_box = CanvasVBox(xalign=hippo.ALIGNMENT_START, yalign=hippo.ALIGNMENT_END)
  
@@ -188,8 +188,8 @@ class AppCategoryUsage(CanvasTable):
         
         self.remove_all()
 
-        self.add(hippo.CanvasText(text="Category", font="Bold 12px", color=0x3F3F3FFF, xalign=hippo.ALIGNMENT_START), left=0, top=0)
-        self.add(hippo.CanvasText(text="Your Usage", font="Bold 12px", color=0x3F3F3FFF, xalign=hippo.ALIGNMENT_START), left=1, top=0)
+        self.add(hippo.CanvasText(text="Category", classes="title", xalign=hippo.ALIGNMENT_START), left=0, top=0)
+        self.add(hippo.CanvasText(text="Your Usage", classes="title", color=0x3F3F3FFF, xalign=hippo.ALIGNMENT_START), left=1, top=0)
         
         categories = categorize(used_apps)
         cat_usage = {}
@@ -243,12 +243,12 @@ class AppExtras(CanvasVBox):
 
         thing = self.__get_section_name()
         self.__left_title = hippo.CanvasText(text="New Popular %s" % (thing,),
-                                             font="12px Bold",
+                                             classes="title",
                                              xalign=hippo.ALIGNMENT_START)
         self.__headerbox.append(self.__left_title)
         # TODO this won't underline properly until ActionLink->set_underline listens for text changes
         # underline=pango.UNDERLINE_LOW
-        self.__right_title = ActionLink(font="12px",
+        self.__right_title = ActionLink(id="more-popular-link",
                                         xalign=hippo.ALIGNMENT_END)
         self.__right_title.connect("activated", self.__on_more_popular)
         self.__headerbox.append(self.__right_title, hippo.PACK_EXPAND)
@@ -491,8 +491,8 @@ class AppList(CanvasVBox):
             self.emit("launch")
              
 class AppBrowser(BigWindow):
-    def __init__(self):
-        super(AppBrowser, self).__init__(themed=False)
+    def __init__(self, stylesheet):
+        super(AppBrowser, self).__init__(stylesheet=stylesheet, themed=False)
 
         self.__repo = apps.get_apps_repo()
         
@@ -508,8 +508,8 @@ class AppBrowser(BigWindow):
         self.__left_box.set_property('background-color', 0xEEEEEEFF)
         self.__box.append(self.__left_box)
         
-        self.__search_text = hippo.CanvasText(text="Search All Applications:", font="Bold 12px",
-                                              color=0x3F3F3FFF, xalign=hippo.ALIGNMENT_START)
+        self.__search_text = hippo.CanvasText(text="Search All Applications:", classes="title",
+                                              xalign=hippo.ALIGNMENT_START)
         self.__left_box.append(self.__search_text)
         self.__search_input = hippo.CanvasEntry()
         #self.__search_input.set_property('border-color', 0xAAAAAAFF)
@@ -529,8 +529,7 @@ class AppBrowser(BigWindow):
         self.__cat_usage = AppCategoryUsage()
         self.__left_box.append(self.__cat_usage)   
 
-        self.__left_box.append(hippo.CanvasText(text="Tools", font="Bold 12px",
-                                                color=0x3F3F3FFF, xalign=hippo.ALIGNMENT_START))
+        self.__left_box.append(hippo.CanvasText(text="Tools", classes="title", xalign=hippo.ALIGNMENT_START))
                                                                
         browse_link = ActionLink(text="Find New Applications", underline=pango.UNDERLINE_LOW, xalign=hippo.ALIGNMENT_START)
         browse_link.connect("button-press-event", lambda l,e: self.__on_browse_popular_apps())
