@@ -1,4 +1,3 @@
-import cgi
 import os
 import time
 import logging
@@ -10,28 +9,22 @@ import hippo
 import bigboard
 from bigboard.databound import DataBoundItem
 from bigboard.big_widgets import ActionLink, CanvasMugshotURLImage, Header
-from bigboard.big_widgets import CanvasMugshotURLImageButton, PhotoContentItem, CanvasHBox, CanvasVBox
+from bigboard.big_widgets import PhotoContentItem, CanvasHBox, CanvasVBox
+from bigboard.big_widgets import BigWindow
 import bigboard.libbig as libbig
+from bigboard.libbig.logutil import log_except
 import bigboard.globals as globals
-
 from bigboard.libbig.format_escaped import format_escaped
 
 from ddm import DataModel
 
+import imclient
+
 _logger = logging.getLogger("bigboard.stocks.PeopleStock")
 
 STATUS_MUSIC = 0
 STATUS_IM = 1
 
-def _open_aim(aim):
-    ## purple-remote only allows lowercase "goim" here, unfortunately I'm guessing 
-    ## some other gnome-open handlers only allow "GoIM" ...
-    os.spawnlp(os.P_NOWAIT, 'gnome-open', 'gnome-open', 'aim:goim?screenname=' + cgi.escape(aim))
-
-def _open_xmpp(xmpp):
-    # FIXME, is there some less hardcoded way to do this?
-    os.spawnlp(os.P_NOWAIT, 'purple-remote', 'purple-remote', 'jabber:goim?screenname=' + cgi.escape(xmpp))
-
 def _open_webdav(url):
     # We pass around WebDAV URL's using the standard http:// scheme, but nautilus wants dav://
     # instead.
@@ -79,13 +72,14 @@ class PersonItem(PhotoContentItem):
         'sort-changed': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, ()),
         'destroy': 'override',
     }
-    
-    def __init__(self, person, themed=False, **kwargs):
+
+    @log_except(_logger)
+    def __init__(self, person, **kwargs):
+        _logger.debug("Initializing %s", self)
+
         PhotoContentItem.__init__(self, **kwargs)
         self.person = person
         
-        self.__themed = themed
-        
         model = DataModel(bigboard.globals.server_name)
 
         self.set_clickable(True)
@@ -146,7 +140,10 @@ class PersonItem(PhotoContentItem):
         self.__update_aim_buddy(self.person)
         self.__update_xmpp_buddy(self.person)
 
+        _logger.debug("Initialized %s", self)
+        
     def do_destroy(self):
+        _logger.debug("Destroying %s", self)
         for handler_id in self.__handlers:
             self.person.disconnect(handler_id)
 
@@ -357,7 +354,7 @@ class AimIcon(IMIcon):
         return "AIM"
 
     def _start_conversation(self):
-        _open_aim(self.resource.name)
+        imclient.get_default().open_chat(self.resource.name, 'aim')
         return True
 
 class XMPPIcon(IMIcon):
@@ -371,7 +368,7 @@ class XMPPIcon(IMIcon):
             return "XMPP"
 
     def _start_conversation(self):
-        _open_xmpp(self.resource.name)
+        imclient.get_default().open_chat(self.resource.name, 'jabber')
         return True
 
 
@@ -406,14 +403,14 @@ class TrackItem(hippo.CanvasBox, DataBoundItem):
         self.append(details)
 
         artist_text = NoTooltipText(text=track.artist,
-                                    font="12px",
+                                    id="track-artist-text",
                                     classes="subforeground",
                                     xalign=hippo.ALIGNMENT_START,
                                     size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
         details.append(artist_text)
 
         title_text = NoTooltipText(text=track.name,
-                                   font="12px",
+                                   id="track-artist-title",
                                    classes="subforeground",
                                    xalign=hippo.ALIGNMENT_START,
                                    size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
@@ -447,13 +444,15 @@ class TrackItem(hippo.CanvasBox, DataBoundItem):
 
         self.__tooltip_popup.popup()
         
-class TrackPopup(hippo.CanvasWindow, DataBoundItem):
+class TrackPopup(BigWindow, DataBoundItem):
     __gsignals__ = {
         'motion-notify-event': 'override'
        }
         
     def __init__(self, track):
-        hippo.CanvasWindow.__init__(self, gtk.WINDOW_POPUP)
+        stylesheet = os.path.join(os.path.dirname(__file__), 'trackpopup.css')
+
+        BigWindow.__init__(self, type=gtk.WINDOW_POPUP, stylesheet=stylesheet)
         DataBoundItem.__init__(self, track)
 
         self.modify_bg(gtk.STATE_NORMAL, gtk.gdk.Color(0xffff,0xffff,0xffff))
@@ -472,12 +471,12 @@ class TrackPopup(hippo.CanvasWindow, DataBoundItem):
         box.append(details)
 
         artist_text = hippo.CanvasText(text=track.artist,
-                                       font="13px",
+                                       id="artist-text",
                                        xalign=hippo.ALIGNMENT_START)
         details.append(artist_text)
 
         title_text = hippo.CanvasText(text=track.name,
-                                      font="13px",
+                                      id="title-text",
                                       xalign=hippo.ALIGNMENT_START)
         details.append(title_text)
 
@@ -515,45 +514,43 @@ class ProfileItem(hippo.CanvasBox):
         "close": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (bool,))
        }
         
-    def __init__(self, person, themed=False, **kwargs):
+    def __init__(self, person, **kwargs):
         kwargs['orientation'] = hippo.ORIENTATION_VERTICAL
         hippo.CanvasBox.__init__(self, **kwargs)
         self.person = person
 
-        self.__themed = themed
-        if themed:
-            self.__header = Header(topborder=False)
-        else:
-            self.__header = hippo.CanvasGradient(orientation=hippo.ORIENTATION_HORIZONTAL,
-                                                 start_color=0xf2f2f2f2,
-                                                 end_color=0xc8c8c8ff)            
-
+        self.__header = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL, classes="slideout-header")
         self.append(self.__header)
+
+        main_box = hippo.CanvasBox(classes="slideout-main")
+        self.append(main_box)
         
         name_vbox = hippo.CanvasBox(padding=6)
-        self.__name = hippo.CanvasText(font="22px")
+        self.__name = hippo.CanvasText(id='profile-name')
         name_vbox.append(self.__name)
-        rename_link = ActionLink(text='rename', font="10px", xalign=hippo.ALIGNMENT_END)
+        rename_link = ActionLink(text='rename', id="profile-rename-link", xalign=hippo.ALIGNMENT_END)
         name_vbox.append(rename_link)
 
         rename_link.connect('activated', self.__on_rename_activated)
 
         self.__header.append(name_vbox)
 
-        user = self.person.user
-        if user:
-            mugshot_link = ActionLink(text="Mugshot", padding=6)
-            self.__header.append(mugshot_link, flags=hippo.PACK_END)
-            mugshot_link.connect("activated", self.__on_activate_web)
+        if self.person.home_url:
+            if self.person.home_url.find("mugshot.org") >= 0:
+                web_link = ActionLink(text="Mugshot", padding=6)
+            else:
+                web_link = ActionLink(text="Web", padding=6)
+            self.__header.append(web_link, flags=hippo.PACK_END)
+            web_link.connect("activated", self.__on_activate_web)
 
         self.__top_box = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL)
-        self.append(self.__top_box)
+        main_box.append(self.__top_box)
 
         self.__photo = CanvasMugshotURLImage(scale_width=60,
                                             scale_height=60,
                                             border=5)
-        
-        if user:
+
+        if self.person.home_url:
             self.__photo.set_clickable(True)
             self.__photo.connect("activated", self.__on_activate_web)
 
@@ -564,28 +561,28 @@ class ProfileItem(hippo.CanvasBox):
 
         self.__contact_status_box = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL,
                                                     spacing=4, border=4)
-        self.append(self.__contact_status_box)
+        main_box.append(self.__contact_status_box)
 
         if person.contact:
             self.__remove_link = ActionLink()
             self.__remove_link.connect('activated', self.__remove_from_network_clicked)
-            self.append(self.__remove_link)
+            main_box.append(self.__remove_link)
         else:
             self.__remove_link = None
         
 #        self.__online = hippo.CanvasText(text='Offline')
-#        self.append(self.__online)
+#        main_box.append(self.__online)
 
         separator = hippo.CanvasBox(box_height=1, background_color=0xAAAAAAFF)
-        self.append(separator)
+        main_box.append(separator)
 
         self.__ribbon_bar = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL,
                                            spacing=2, border=4)
-        self.append(self.__ribbon_bar)
+        main_box.append(self.__ribbon_bar)
 
         self.__link_box = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL,
                                           spacing=2, border=4)
-        self.append(self.__link_box)
+        main_box.append(self.__link_box)
         
         self.__local_files_link = None
 
@@ -826,7 +823,8 @@ class ProfileItem(hippo.CanvasBox):
 
     def __on_activate_web(self, canvas_item):
         self.emit("close", True)
-        libbig.show_url(self.person.user.homeUrl)
+        if self.person.home_url:
+            libbig.show_url(self.person.home_url)
 
     def __on_activate_email(self, canvas_item, addr):
         self.emit("close", True)
@@ -835,11 +833,11 @@ class ProfileItem(hippo.CanvasBox):
 
     def __on_activate_aim(self, canvas_item, addr):
         self.emit("close", True)
-        _open_aim(addr)
+        imclient.get_default().open_chat(self.resource.name, 'aim')
         
     def __on_activate_xmpp(self, canvas_item, addr):
         self.emit("close", True)
-        _open_xmpp(addr)
+        imclient.get_default().open_chat(self.resource.name, 'jabber')
 
     def __on_activate_add_address(self, canvas_item):
         dialog = gtk.Dialog(title=("Add an address for %s" % self.person.display_name))
